#
# Interface versions exposed by PHP:
# 
%@SCL@php_core_api 20240924
%@SCL@php_zend_api 20240924
%@SCL@php_pdo_api  20240423
%@SCL@php_version  @PHP_VERSION@

%@SCL@php_extdir   @LIBDIR@/php/modules

%@SCL@php_inidir   @ETCDIR@/php.d

%@SCL@php_incldir  @INCDIR@/php

%@SCL@__php        @BINDIR@/php

